CrewBuilder class

Constructors

CrewBuilder()

Properties

creditId String?
getter/setter pair
department String?
getter/setter pair
gender num?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id num?
getter/setter pair
job String?
getter/setter pair
name String?
getter/setter pair
profilePath String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build() Crew
Builds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(Crew other) → void
Replaces the value in the builder with a new one.
override
toString() String
A string representation of this object.
inherited
update(void updates(CrewBuilder)?) → void
Applies updates.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited