GotifySettings class abstract

GotifySettings

Properties:

Annotations
  • @BuiltValue.new()

Constructors

GotifySettings([void updates(GotifySettingsBuilder b)])
factory

Properties

enabled bool?
no setter
hashCode int
The hash code for this object.
no setterinherited
options GotifySettingsOptions?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
types num?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(GotifySettingsBuilder)) GotifySettings
Rebuilds the instance.
inherited
toBuilder() GotifySettingsBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<GotifySettings>
no setter