JobBuilder class

Constructors

JobBuilder()

Properties

hashCode int
The hash code for this object.
no setterinherited
id String?
getter/setter pair
interval JobIntervalEnum?
getter/setter pair
name String?
getter/setter pair
nextExecutionTime String?
getter/setter pair
running bool?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type JobTypeEnum?
getter/setter pair

Methods

build() Job
Builds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(Job other) → void
Replaces the value in the builder with a new one.
override
toString() String
A string representation of this object.
inherited
update(void updates(JobBuilder)?) → void
Applies updates.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited