MainSettings class abstract

Annotations
  • @BuiltValue.new()

Constructors

MainSettings([void updates(MainSettingsBuilder b)])
factory

Properties

apiKey String?
no setter
appLanguage String?
no setter
applicationTitle String?
no setter
applicationUrl String?
no setter
defaultPermissions num?
no setter
enableSpecialEpisodes bool?
no setter
hashCode int
The hash code for this object.
no setterinherited
hideAvailable bool?
no setter
localLogin bool?
no setter
mediaServerType num?
no setter
newPlexLogin bool?
no setter
partialRequestsEnabled bool?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(MainSettingsBuilder)) MainSettings
Rebuilds the instance.
inherited
toBuilder() MainSettingsBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<MainSettings>
no setter