MediaMediaIdWatchDataGet200Response class abstract
- Annotations
-
- @BuiltValue.new()
Constructors
- MediaMediaIdWatchDataGet200Response([void updates(MediaMediaIdWatchDataGet200ResponseBuilder b)])
-
factory
Properties
- data → MediaMediaIdWatchDataGet200ResponseData?
-
no setter
- data4k → MediaMediaIdWatchDataGet200ResponseData?
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
dynamic updates(MediaMediaIdWatchDataGet200ResponseBuilder)) → MediaMediaIdWatchDataGet200Response -
Rebuilds the instance.
inherited
-
toBuilder(
) → MediaMediaIdWatchDataGet200ResponseBuilder -
Converts the instance to a builder
B.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
serializer
→ Serializer<
MediaMediaIdWatchDataGet200Response> -
no setter