OtherApi class

Constructors

OtherApi(Dio _dio, Serializers _serializers)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

certificationsMovieGet({CancelToken? cancelToken, Map<String, dynamic>? headers, Map<String, dynamic>? extra, ValidateStatus? validateStatus, ProgressCallback? onSendProgress, ProgressCallback? onReceiveProgress}) Future<Response<CertificationResponse>>
Get movie certifications Returns list of movie certifications from TMDB.
certificationsTvGet({CancelToken? cancelToken, Map<String, dynamic>? headers, Map<String, dynamic>? extra, ValidateStatus? validateStatus, ProgressCallback? onSendProgress, ProgressCallback? onReceiveProgress}) Future<Response<CertificationResponse>>
Get TV certifications Returns list of TV show certifications from TMDB.
keywordKeywordIdGet({required num keywordId, CancelToken? cancelToken, Map<String, dynamic>? headers, Map<String, dynamic>? extra, ValidateStatus? validateStatus, ProgressCallback? onSendProgress, ProgressCallback? onReceiveProgress}) Future<Response<Keyword>>
Get keyword Returns a single keyword in JSON format.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
watchprovidersMoviesGet({required String watchRegion, CancelToken? cancelToken, Map<String, dynamic>? headers, Map<String, dynamic>? extra, ValidateStatus? validateStatus, ProgressCallback? onSendProgress, ProgressCallback? onReceiveProgress}) Future<Response<BuiltList<WatchProviderDetails>>>
Get watch provider movies Returns a list of all available watch providers for movies.
watchprovidersRegionsGet({CancelToken? cancelToken, Map<String, dynamic>? headers, Map<String, dynamic>? extra, ValidateStatus? validateStatus, ProgressCallback? onSendProgress, ProgressCallback? onReceiveProgress}) Future<Response<BuiltList<WatchProviderRegion>>>
Get watch provider regions Returns a list of all available watch provider regions.
watchprovidersTvGet({required String watchRegion, CancelToken? cancelToken, Map<String, dynamic>? headers, Map<String, dynamic>? extra, ValidateStatus? validateStatus, ProgressCallback? onSendProgress, ProgressCallback? onReceiveProgress}) Future<Response<BuiltList<WatchProviderDetails>>>
Get watch provider series Returns a list of all available watch providers for series.

Operators

operator ==(Object other) bool
The equality operator.
inherited