OverrideRule class abstract

OverrideRule

Properties:

Annotations
  • @BuiltValue.new()

Constructors

OverrideRule([void updates(OverrideRuleBuilder b)])
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
id String?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(OverrideRuleBuilder)) OverrideRule
Rebuilds the instance.
inherited
toBuilder() OverrideRuleBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<OverrideRule>
no setter