PersonDetailsBuilder class
Constructors
Properties
- adult ↔ bool?
-
getter/setter pair
-
alsoKnownAs
↔ ListBuilder<
String> -
getter/setter pair
- biography ↔ String?
-
getter/setter pair
- deathday ↔ String?
-
getter/setter pair
- gender ↔ String?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- homepage ↔ String?
-
getter/setter pair
- id ↔ num?
-
getter/setter pair
- imdbId ↔ String?
-
getter/setter pair
- knownForDepartment ↔ String?
-
getter/setter pair
- name ↔ String?
-
getter/setter pair
- placeOfBirth ↔ String?
-
getter/setter pair
- popularity ↔ String?
-
getter/setter pair
- profilePath ↔ String?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
) → PersonDetails -
Builds.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
replace(
PersonDetails other) → void -
Replaces the value in the builder with a new one.
override
-
toString(
) → String -
A string representation of this object.
inherited
-
update(
void updates(PersonDetailsBuilder)?) → void -
Applies updates.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited