RadarrSettings class abstract

Annotations
  • @BuiltValue.new()

Constructors

RadarrSettings([void updates(RadarrSettingsBuilder b)])
factory

Properties

activeDirectory String
no setter
activeProfileId num
no setter
activeProfileName String
no setter
apiKey String
no setter
baseUrl String?
no setter
externalUrl String?
no setter
hashCode int
The hash code for this object.
no setterinherited
hostname String
no setter
id num?
no setter
is4k bool
no setter
isDefault bool
no setter
minimumAvailability String
no setter
name String
no setter
port num
no setter
preventSearch bool?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
syncEnabled bool?
no setter
useSsl bool
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(RadarrSettingsBuilder)) RadarrSettings
Rebuilds the instance.
inherited
toBuilder() RadarrSettingsBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<RadarrSettings>
no setter