SearchKeywordGet200Response class abstract

SearchKeywordGet200Response

Properties:

Annotations
  • @BuiltValue.new()

Constructors

SearchKeywordGet200Response([void updates(SearchKeywordGet200ResponseBuilder b)])
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
page num?
no setter
results → BuiltList<Keyword>?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalPages num?
no setter
totalResults num?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(SearchKeywordGet200ResponseBuilder)) SearchKeywordGet200Response
Rebuilds the instance.
inherited
toBuilder() SearchKeywordGet200ResponseBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<SearchKeywordGet200Response>
no setter