ServiceRadarrRadarrIdGet200Response class abstract
- Annotations
-
- @BuiltValue.new()
Constructors
- ServiceRadarrRadarrIdGet200Response([void updates(ServiceRadarrRadarrIdGet200ResponseBuilder b)])
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- profiles → ServiceProfile?
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- server → RadarrSettings?
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
dynamic updates(ServiceRadarrRadarrIdGet200ResponseBuilder)) → ServiceRadarrRadarrIdGet200Response -
Rebuilds the instance.
inherited
-
toBuilder(
) → ServiceRadarrRadarrIdGet200ResponseBuilder -
Converts the instance to a builder
B.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
serializer
→ Serializer<
ServiceRadarrRadarrIdGet200Response> -
no setter