TvResult class abstract

Annotations
  • @BuiltValue.new()

Constructors

TvResult([void updates(TvResultBuilder b)])
factory

Properties

backdropPath String?
no setter
firstAirDate String?
no setter
genreIds → BuiltList<num>?
no setter
hashCode int
The hash code for this object.
no setterinherited
id num?
no setter
mediaInfo MediaInfo?
no setter
mediaType String?
no setter
name String?
no setter
originalLanguage String?
no setter
originalName String?
no setter
originCountry → BuiltList<String>?
no setter
overview String?
no setter
popularity num?
no setter
posterPath String?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
voteAverage num?
no setter
voteCount num?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(TvResultBuilder)) TvResult
Rebuilds the instance.
inherited
toBuilder() TvResultBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<TvResult>
no setter